const {promisify} = require('util');
const gzip = promisify(require('zlib').gzip);

const util = require('./util');

// Preprocess files to provide a gzip compressed alternative version
function Preprocessor(config, logger) {
  const log = logger.create('preprocessor.gzip');

  return (content, file) => {
    const originalSize = content.length;
    const contentBuffer = Buffer.isBuffer(content) ? content : Buffer.from(content);

    gzip(contentBuffer)
      .then(
        gzippedContent => {
          // eslint-disable-next-line no-param-reassign
          file.encodings.gzip = gzippedContent;

          log.info(`compressed ${file.originalPath} [${util.bytesToSize(originalSize)} -> ${util.bytesToSize(gzippedContent.length)}]`);
          return content;
        },
        error => {
          log.error(error);
          return Promise.reject(error);
        }
      );
  };
}

Preprocessor.$inject = ['config.gzip', 'logger'];

module.exports = Preprocessor;
